summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/buttons/nontdeappbutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker/buttons/nontdeappbutton.h')
-rw-r--r--kicker/kicker/buttons/nontdeappbutton.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kicker/kicker/buttons/nontdeappbutton.h b/kicker/kicker/buttons/nontdeappbutton.h
index 94c7cb59d..eac6ce412 100644
--- a/kicker/kicker/buttons/nontdeappbutton.h
+++ b/kicker/kicker/buttons/nontdeappbutton.h
@@ -37,8 +37,8 @@ class PanelExeDialog;
*/
class NonKDEAppButton : public PanelButton
{
- // the Q_OBJECT macro provides the magic glue for signals 'n slots
- Q_OBJECT
+ // the TQ_OBJECT macro provides the magic glue for signals 'n slots
+ TQ_OBJECT
public:
// define our two constructors, one used for creating new buttons...